# coding: utf-8

"""
    OpenBuckets API

    The OpenBuckets web-based tool is a powerful utility that allows users to quickly locate open buckets in cloud storage systems through a simple query. In addition, it provides a convenient way to search for various file types across these open buckets, making it an essential tool for security professionals, researchers, and anyone interested in discovering exposed data. This Postman collection aims to showcase the capabilities of OpenBuckets by providing a set of API requests that demonstrate how to leverage its features. By following this collection, you'll learn how to utilize OpenBuckets to identify open buckets and search for specific file types within them.

    The version of the OpenAPI document: 1.0.0
    Contact: support@openbuckets.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional, Union
from pydantic import BaseModel, Field, StrictFloat, StrictInt, StrictStr

class FileSearchResultsFilesInner(BaseModel):
    """
    Details about each file.
    """
    bucket_id: Optional[Union[StrictFloat, StrictInt]] = Field(None, alias="bucketId", description="The unique identifier for the bucket containing the file.")
    cloud_provider: Optional[StrictStr] = Field(None, alias="cloudProvider", description="The cloud provider where the file is hosted.")
    file_extension: Optional[StrictStr] = Field(None, alias="fileExtension", description="The file extension.")
    file_name: Optional[StrictStr] = Field(None, alias="fileName", description="The name of the file.")
    file_size: Optional[Union[StrictFloat, StrictInt]] = Field(None, alias="fileSize", description="The size of the file in bytes.")
    file_url: Optional[StrictStr] = Field(None, alias="fileUrl", description="The URL of the file.")
    full_path: Optional[StrictStr] = Field(None, alias="fullPath", description="The full path to the file.")
    id: Optional[Union[StrictFloat, StrictInt]] = Field(None, description="The unique identifier for the file.")
    indexed_at: Optional[datetime] = Field(None, alias="indexedAt", description="The date and time when the file was last indexed.")
    last_modified: Optional[datetime] = Field(None, alias="lastModified", description="The date and time when the file was last modified.")
    __properties = ["bucketId", "cloudProvider", "fileExtension", "fileName", "fileSize", "fileUrl", "fullPath", "id", "indexedAt", "lastModified"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> FileSearchResultsFilesInner:
        """Create an instance of FileSearchResultsFilesInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> FileSearchResultsFilesInner:
        """Create an instance of FileSearchResultsFilesInner from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return FileSearchResultsFilesInner.parse_obj(obj)

        _obj = FileSearchResultsFilesInner.parse_obj({
            "bucket_id": obj.get("bucketId"),
            "cloud_provider": obj.get("cloudProvider"),
            "file_extension": obj.get("fileExtension"),
            "file_name": obj.get("fileName"),
            "file_size": obj.get("fileSize"),
            "file_url": obj.get("fileUrl"),
            "full_path": obj.get("fullPath"),
            "id": obj.get("id"),
            "indexed_at": obj.get("indexedAt"),
            "last_modified": obj.get("lastModified")
        })
        return _obj


